@@ -1,3 +1,5 @@
+import json
+
 from qm_spider import *
 
 
@@ -321,26 +323,30 @@ class Get_ASM_Consume:
             dingding_push.status_push()
             return '...登陆异常，请重试...'
 
+    def get_soid_token(self, company_name):
+        url = 'https://app-ads.apple.com/cm/api/v1/startup/orgs'
+        headers = {
+            'Host': 'app-ads.apple.com',
+            'Connection': 'keep-alive',
+            'Content-Type': 'application/json;charset=UTF-8',
+            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
+            'X-XSRF-TOKEN-CM': self.res_token_cm
+        }
+        res = session.get(url, headers=headers)
+        for org_info in res.json()['data']['orgDetails']:
+            if org_info['name'] == company_name:
+                s = requests.cookies.RequestsCookieJar()
+                s.set('searchads.soid', org_info['id'])
+                session.cookies.update(s)
+                break
+        return session
+
     def get_asm_fileList(self, company_name=''):
         """
             * 获取中国区ASA账号上提交的资料列表及数据；
         """
         if len(company_name) > 0:
-            url = 'https://app-ads.apple.com/cm/api/v1/startup/orgs'
-            headers = {
-                'Host': 'app-ads.apple.com',
-                'Connection': 'keep-alive',
-                'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
-                'X-XSRF-TOKEN-CM': self.res_token_cm
-            }
-            res = session.get(url, headers=headers)
-            for org_info in res.json()['data']['orgDetails']:
-                if org_info['name'] == company_name:
-                    s = requests.cookies.RequestsCookieJar()
-                    s.set('searchads.soid', org_info['id'])
-                    session.cookies.update(s)
-                    break
+            self.get_soid_token(company_name)
         url = 'https://app-ads.apple.com/cm/api/v1/doc/find'
         offset_num = 0
         res_list = []
@@ -381,35 +387,21 @@ class Get_ASM_Consume:
             * 获取中国区ASA账号审核状态列表；
         """
         if len(company_name) > 0:
-            url = 'https://app-ads.apple.com/cm/api/v1/startup/orgs'
-            headers = {
-                'Host': 'app-ads.apple.com',
-                'Connection': 'keep-alive',
-                'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
-                'X-XSRF-TOKEN-CM': self.res_token_cm
-            }
-            res = session.get(url, headers=headers)
-            for org_info in res.json()['data']['orgDetails']:
-                if org_info['name'] == company_name:
-                    s = requests.cookies.RequestsCookieJar()
-                    s.set('searchads.soid', org_info['id'])
-                    session.cookies.update(s)
-                    break
+            self.get_soid_token(company_name)
         url = 'https://app-ads.apple.com/cm/api/v1/approval/find'
         offset_num = 0
         res_list = []
         appid_list = []
+        headers = {
+            'Host': 'app-ads.apple.com',
+            'Connection': 'keep-alive',
+            'Content-Type': 'application/json',
+            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36 Edg/91.0.864.67',
+            'X-XSRF-TOKEN-CM': self.res_token_cm
+        }
         while True:
             print('正在获取第【%s】页的APP审核信息列表' %(int(offset_num/50+1)))
             payload = {"pagination":{"offset":offset_num,"limit":100}}
-            headers = {
-                'Host': 'app-ads.apple.com',
-                'Connection': 'keep-alive',
-                'Content-Type': 'application/json',
-                'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36 Edg/91.0.864.67',
-                'X-XSRF-TOKEN-CM': self.res_token_cm
-            }
             res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
             if len(res.json()['data']) > 0 and res.json()['data'][0] not in appid_list:
                 app_list = [i for i in res.json()['data']]
@@ -420,6 +412,55 @@ class Get_ASM_Consume:
                 break
         return res_list
 
+    def get_plan_status(self, soid, start_date=today_date-datetime.timedelta(6), end_date=today_date):
+        s = requests.cookies.RequestsCookieJar()
+        s.set('searchads.soid', str(soid))
+        session.cookies.update(s)
+        # 开始请求；
+        url = 'https://app-ads.apple.com/cm/api/v4/reports'
+        offset_num = 0
+        headers = {
+            'Host': 'app-ads.apple.com',
+            'Connection': 'keep-alive',
+            'Content-Type': 'application/json',
+            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36 Edg/91.0.864.67',
+            'X-XSRF-TOKEN-CM': self.res_token_cm
+        }
+        res_list = []
+        while True:
+            payload = {
+                "type": "campaigns",
+                "filter": {
+                    "startTime": str(start_date),
+                    "endTime": str(end_date),
+                    "timeZone": "UTC",
+                    "returnGrandTotals": True,
+                    "returnRowTotals": True,
+                    "selector": {
+                        "pagination": {
+                            "offset": offset_num,
+                            "limit": 50
+                        },
+                        "orderBy": [
+                            {
+                                "field": "localSpend",
+                                "sortOrder": "DESCENDING"
+                            }
+                        ]
+                    },
+                    "returnRecordsWithNoMetrics": True
+                }
+            }
+            res = session.post(url, data=json.dumps(payload), headers=headers, verify=False)
+            print(res.json())
+            if len(res.json()['data']['row']) > 0:
+                res_list.append(res.json())
+                offset_num += 50
+            else:
+                break
+        return res_list
+
+
 # 封装获取账单的脚本；
 class Get_ASM_Bill(Get_ASM_Consume):
     def __init__(self, accountName, accountPwd, start_date, end_date):
